<?php 
class WCPS_Customer
{
	public function __construct()
	{
		if(is_admin())
		{
			add_action('wp_ajax_wcps_get_customers_list', array(&$this, 'ajax_get_customer_partial_list'));
		}
	}
	public function get_num_purchased_per_item($product_id, $current_user = null)
	{
		global $wpdb;
		if(!isset($current_user))
			$current_user = get_current_user_id();
		if($current_user == 0) //guest
			return -1;
		
		$query = "SELECT meta_value
				   FROM {$wpdb->usermeta} 
				   WHERE user_id = {$current_user} 
				   AND meta_key = 'wcps_item-{$product_id}' ";
		
		$result = $wpdb->get_results($query);
		return isset($result[0]) ? $result[0]->meta_value : 0;
	}
	public function get_all_user_who_bought($product_id)
	{
		global $wpdb;
		$current_user =  get_current_user_id();
		if($current_user == 0)
			return -1;
		
		$string = "SELECT usermeta.user_id, usermeta.meta_value AS quantity, user.user_email AS email, usermeta2.meta_value AS name, usermeta3.meta_value AS surname
				   FROM {$wpdb->usermeta} AS usermeta
				   INNER JOIN {$wpdb->users} AS user ON user.ID = usermeta.user_id
				   INNER JOIN {$wpdb->usermeta} AS usermeta2 ON usermeta2.user_id = usermeta.user_id
				   INNER JOIN {$wpdb->usermeta} AS usermeta3 ON usermeta3.user_id = usermeta.user_id
				   WHERE usermeta.meta_key = 'wcps_item-{$product_id}' 
				   AND usermeta2.meta_key = 'first_name' 
				   AND usermeta3.meta_key = 'last_name' 
				   AND usermeta.meta_value > 0
				   GROUP BY usermeta.user_id";
		
		$result = $wpdb->get_results($string);
		//wcps_var_dump($result);
		return isset($result) ? $result : false;
	}
	public function update_presale_meta_info($user_id, $product_id,/*  $variation_id, */ $quantity, $absolute_value = false ,$reduce = false)
	{
		$name = "wcps_item-".$product_id;
		/* if(isset($variation_id) && $variation_id != '')
			$name.= "-".$variation_id; */
		
		if($quantity == 0 && $absolute_value)
		{
			delete_user_meta($user_id, $name);
		}
		else
		{
			if(!$absolute_value)
			{
				$quantity_old = $this->get_num_purchased_per_item($product_id, $user_id);
				if(!$reduce)
					$quantity += $quantity_old;
				else
				{
					$quantity = $quantity_old - $quantity;
					if($quantity < 0 )
						$quantity = 0;
				}
			}
			update_user_meta($user_id, $name, $quantity);
		}
		
	}
	public function update_deposit_meta_info($user_id, $product_id, $variation_id, $quantity, $reduce = false, $only_if_exists = false)
	{
		if(!isset($user_id))
			$user_id = get_current_user_id();
		if($user_id == 0) //guest
			return -1;
			
		$name = "wcps_item-deposit-".$product_id;
		if($variation_id > 0)
			$name .= "_".$variation_id;
		
		$quantity_old = $this->has_a_deposit_for_product($product_id, $variation_id, $user_id);
		
		
		if($only_if_exists)
		{
			if($quantity_old > 0)
			{
				$quantity = $quantity_old - $quantity;
				if($quantity < 0 )
					$quantity = 0;
				
				update_user_meta($user_id, $name, $quantity);
			}
			return;
		}
		else
		{
			$quantity_old = $quantity_old < 0 ? 0 : $quantity_old;
			if(!$reduce)
				$quantity += $quantity_old;
			else
			{
				$quantity = $quantity_old - $quantity;
				if($quantity < 0 )
					$quantity = 0;
			}
		}
		
		update_user_meta($user_id, $name, $quantity);
	}
	//returns quantity
	public function has_a_deposit_for_product($product_id, $variation_id, $user_id = null)
	{
		if(!isset($product_id))
			return -1;
		if(!isset($user_id))
			$user_id = get_current_user_id();
		if($user_id == 0) //guest
			return -1;
			
		$name = "wcps_item-deposit-".$product_id;
		if($variation_id > 0)
			$name .= "_".$variation_id;
		$result = get_user_meta($user_id, $name, true);
		
		return is_numeric($result) ? $result :-1;
	}
	public function ajax_get_customer_partial_list()
	 {
		 $customers = $this->get_customer_list($_GET['customer']);
		 echo json_encode( $customers);
		 wp_die();
	 }
	 public function get_customer_list($search_string = null)
	 {
		 global $wpdb;
		 $query_string = "SELECT customers.ID as customer_id, usermeta_name.meta_value as first_name, usermeta_surname.meta_value as last_name, usermeta_email.meta_value as email
							 FROM {$wpdb->users} AS customers
							 LEFT JOIN {$wpdb->usermeta} AS usermeta_name ON customers.ID = usermeta_name.user_id AND usermeta_name.meta_key = 'billing_first_name'
							 LEFT JOIN {$wpdb->usermeta} AS usermeta_surname ON customers.ID = usermeta_surname.user_id AND usermeta_surname.meta_key = 'billing_last_name'
							 LEFT JOIN {$wpdb->usermeta} AS usermeta_email ON customers.ID = usermeta_email.user_id AND usermeta_email.meta_key = 'billing_email'
							 LEFT JOIN {$wpdb->postmeta} AS postmeta ON postmeta.meta_value = customers.ID  AND   postmeta.meta_key = '_customer_user'	";					 
							
		if($search_string)
				$query_string .=  " WHERE ( usermeta_name.meta_value LIKE '%{$search_string}%' OR  usermeta_surname.meta_value LIKE '%{$search_string}%' OR usermeta_email.meta_value LIKE '%{$search_string}%')";
		
		$query_string .=  " GROUP BY customers.ID ";
		return $wpdb->get_results($query_string );
	 }
}
?>